SystemOrganization addCategory: #ConfigurationOfSightTagging!

Object subclass: #ConfigurationOfSightTagging
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSightTagging'!

!ConfigurationOfSightTagging commentStamp: '<historical>' prior: 0!
Copy me to create a new configuration or edit and evaluate the following doits.

        "Create configuration class and initial baseline method"

        MetacelloToolBox 
                createBaseline: '1.0-baseline'
                for: 'MyProject'
                repository: 'http://www.example.com/MyProjectRepository'
                requiredProjects: #('Gofer')
                packages: #('MyProject-Core' 'MyProject-Tests')
                dependencies:
                        {('MyProject-Core' -> #('Gofer')).
                         ('MyProject-Tests' -> #('MyProject-Core'))}
                groups:
                        {('default' -> #('Core')).
                        ('Core' -> #('MyProject-Core')).
                        ('Tests' -> #('MyProject-Tests'))}.

	   "create initial development method from the baseline"

         MetacelloToolBox
               createDevelopment: '1.0'
               for: 'MyProject'
                importFromBaseline: '1.0-baseline'
                description: 'initial version'.
!

!ConfigurationOfSightTagging class methodsFor: 'development support' stamp: 'lt 8/1/2012 13:35:10.599'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfSightTagging class methodsFor: 'private' stamp: 'lt 8/1/2012 13:35:10.614'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfSightTagging class methodsFor: 'private' stamp: 'lt 8/1/2012 13:35:10.621'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfSightTagging class methodsFor: 'private' stamp: 'lt 8/1/2012 13:35:10.628'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfSightTagging class methodsFor: 'metacello tool support' stamp: 'lt 8/1/2012 13:35:10.633'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSightTagging class methodsFor: 'loading' stamp: 'lt 8/1/2012 13:35:10.637'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfSightTagging class methodsFor: 'loading' stamp: 'lt 8/1/2012 13:35:10.642'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfSightTagging class methodsFor: 'loading' stamp: 'lt 8/1/2012 13:35:10.646'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfSightTagging class methodsFor: 'accessing' stamp: 'lt 8/1/2012 13:35:10.651'!
project

	^self new project! !

!ConfigurationOfSightTagging class methodsFor: 'development support' stamp: 'lt 8/1/2012 13:35:10.608'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfSightTagging methodsFor: 'baselines' stamp: 'lt 8/1/2012 13:42:29.218'!
baseline100: spec 
	<version: '1.0-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/CodeSight'.

		spec 
			package: 'Sight-Tagging';
			group: 'default' with: #('Sight-Tagging')].! !

!ConfigurationOfSightTagging methodsFor: 'symbolic versions' stamp: 'lt 8/1/2012 13:55:31.911'!
development: spec 
	<symbolicVersion: #development>
	
	spec for: #'common' version: '0.1'.
! !

!ConfigurationOfSightTagging methodsFor: 'accessing' stamp: 'lt 8/1/2012 13:35:10.589'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfSightTagging methodsFor: 'versions' stamp: 'lt 8/1/2012 13:45:20.61'!
version010: spec
	<version: '0.1' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #development.
		spec author: 'Lauritz Thamsen'.
			
		spec
			package: 'Sight-Tagging' with: 'Sight-Tagging-mt.1'].! !
